# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from automio.models.invoke_parallel_call_request_data_list_inner_connection_id import InvokeParallelCallRequestDataListInnerConnectionId
from automio.models.invoke_parallel_call_request_data_list_inner_organization_id import InvokeParallelCallRequestDataListInnerOrganizationId
from typing import Optional, Set
from typing_extensions import Self

class InvokeParallelCallRequestDataListInner(BaseModel):
    """
    InvokeParallelCallRequestDataListInner
    """ # noqa: E501
    connection_id: InvokeParallelCallRequestDataListInnerConnectionId
    organization_id: Optional[InvokeParallelCallRequestDataListInnerOrganizationId] = None
    params: Optional[Dict[str, Any]] = Field(default=None, description="Query parameters for the request")
    data: Optional[Dict[str, Any]] = Field(default=None, description="Request body data")
    url_params: Optional[Dict[str, Any]] = Field(default=None, description="URL parameters to replace in the URL")
    __properties: ClassVar[List[str]] = ["connection_id", "organization_id", "params", "data", "url_params"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InvokeParallelCallRequestDataListInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connection_id
        if self.connection_id:
            _dict['connection_id'] = self.connection_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of organization_id
        if self.organization_id:
            _dict['organization_id'] = self.organization_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InvokeParallelCallRequestDataListInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "connection_id": InvokeParallelCallRequestDataListInnerConnectionId.from_dict(obj["connection_id"]) if obj.get("connection_id") is not None else None,
            "organization_id": InvokeParallelCallRequestDataListInnerOrganizationId.from_dict(obj["organization_id"]) if obj.get("organization_id") is not None else None,
            "params": obj.get("params"),
            "data": obj.get("data"),
            "url_params": obj.get("url_params")
        })
        return _obj


